@@ -1,24 +1,25 @@
 #    Copyright (c) 2014 Mirantis, Inc.
 #
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    Licensed under the Apache License, Version 2.0 (the 'License'); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
 #
 #         http://www.apache.org/licenses/LICENSE-2.0
 #
 #    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    distributed under the License is distributed on an 'AS IS' BASIS, WITHOUT
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import logging
+
+from django.utils.translation import ugettext_lazy as _
 from horizon import tabs
 
-from django.utils.translation import gettext_lazy as _
-from oslo_log import log as logging
-
 from muranodashboard.dynamic_ui import services
 
+
 LOG = logging.getLogger(__name__)
 
 
@@ -55,19 +56,19 @@ class AppRequirementsTab(tabs.Tab):
     def _get_requirements(self):
         forms = services.get_app_forms(self.request, {'app_id': self.app.id})
         self.app.requirements = []
-        for step_name, step in forms:
+        for step in forms:
             for key in step.base_fields:
                 # Check for instance size requirements in the UI yaml file.
                 if key == 'flavor':
-                    reqs = getattr(step.base_fields[key], 'requirements', '')
-                    if reqs:
+                    if hasattr(step.base_fields[key], 'requirements'):
+                        reqs = step.base_fields[key].requirements
                         # Make the requirement values screen-printable.
                         self.app.requirements.append('Instance flavor:')
                         requirements = []
                         for req in reqs:
                             if req == 'min_disk':
                                 requirements.append(
-                                    'Minimum disk size: {0} GB'.format(
+                                    'Minimum disk size: {0}GB'.format(
                                         str(reqs[req])))
                             elif req == 'min_vcpus':
                                 requirements.append(
@@ -75,19 +76,7 @@ class AppRequirementsTab(tabs.Tab):
                                         str(reqs[req])))
                             elif req == 'min_memory_mb':
                                 requirements.append(
-                                    'Minimum RAM size: {0} MB'.format(
-                                        str(reqs[req])))
-                            elif req == 'max_disk':
-                                requirements.append(
-                                    'Maximum disk size: {0} GB'.format(
-                                        str(reqs[req])))
-                            elif req == 'max_vcpus':
-                                requirements.append(
-                                    'Maximum vCPUs: {0}'.format(
-                                        str(reqs[req])))
-                            elif req == 'max_memory_mb':
-                                requirements.append(
-                                    'Maximum RAM size: {0} MB'.format(
+                                    'Minimum RAM size: {0}MB'.format(
                                         str(reqs[req])))
                         self.app.requirements.append(requirements)
 
@@ -110,7 +99,7 @@ class AppLicenseAgreementTab(tabs.Tab):
     def _get_license(self):
         forms = services.get_app_forms(self.request, {'app_id': self.app.id})
         self.app.license = ''
-        for step_name, step in forms:
+        for step in forms:
             for key in step.base_fields.keys():
                 # Check for a license in the UI yaml file.
                 if key == 'license':
