@@ -16,41 +16,28 @@ import collections
 import copy
 import functools
 import json
+import logging
 import re
-from urllib import parse
-import uuid
-
-from castellan.common import exception as castellan_exception
 
 from django.conf import settings
 from django.contrib import auth
 from django.contrib.auth import decorators as auth_dec
-from django.templatetags.static import static
-from django.urls import reverse
-# django.contrib.formtools migration to django 1.8
-# https://docs.djangoproject.com/en/1.8/ref/contrib/formtools/
-try:
-    from django.contrib.formtools.wizard import views as wizard_views
-except ImportError:
-    from formtools.wizard import views as wizard_views
+from django.contrib.formtools.wizard import views as wizard_views
+from django.contrib.staticfiles.templatetags.staticfiles import static
+from django.core.urlresolvers import reverse
 from django import http
 from django import shortcuts
 from django.utils import decorators as django_dec
 from django.utils import html
 from django.utils import http as http_utils
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 from django.views.generic import list as list_view
 from horizon import exceptions
 from horizon.forms import views
 from horizon import messages
 from horizon import tabs
-from horizon import views as generic_views
-from novaclient import exceptions as nova_exceptions
-from openstack_dashboard.api import nova
-from openstack_dashboard.usage import quotas
-from oslo_log import log as logging
-
 from muranoclient.common import exceptions as exc
+
 from muranodashboard import api
 from muranodashboard.api import packages as pkg_api
 from muranodashboard.catalog import tabs as catalog_tabs
@@ -59,16 +46,16 @@ from muranodashboard.dynamic_ui import helpers
 from muranodashboard.dynamic_ui import services
 from muranodashboard.environments import api as env_api
 from muranodashboard.environments import consts
-from muranodashboard.packages import consts as pkg_consts
+
 
 LOG = logging.getLogger(__name__)
 ALL_CATEGORY_NAME = 'All'
-LATEST_APPS_QUEUE_LIMIT = 3
+LATEST_APPS_QUEUE_LIMIT = 6
 
 
 class DictToObj(object):
     def __init__(self, **kwargs):
-        for key, value in iter(kwargs.items()):
+        for key, value in kwargs.iteritems():
             setattr(self, key, value)
 
 
@@ -99,37 +86,11 @@ def get_environments_context(request):
     return context
 
 
-def get_categories_list(request):
-    """Returns a list of categories, sorted.
-
-    Categories with packages come first, categories without
-    packages come second. both groups alphabetically sorted.
-    """
-
-    categories = []
-    with api.handled_exceptions(request):
-        client = api.muranoclient(request)
-        categories = client.categories.list()
-
-    # NOTE(kzaitsev) We rely here on tuple comparison and ascending order of
-    # sorted(). i.e. (False, 'a') < (False, 'b') < (True, 'a') < (True, 'b')
-    # So to make order more human-friendly we sort based on
-    # package_count == 0, pushing categories without packages in front and
-    # and then sorting them alphabetically
-    categories = [cat for cat in sorted(
-        categories, key=lambda c: (c.package_count == 0, c.name))]
-    # TODO(kzaitsev): add sorting options to category API
-
-    return categories
-
-
 @auth_dec.login_required
 def switch(request, environment_id,
            redirect_field_name=auth.REDIRECT_FIELD_NAME):
-    redirect_to = request.GET.get(redirect_field_name, '')
-    if (not http_utils.url_has_allowed_host_and_scheme(
-            url=redirect_to,
-            host=request.get_host())):
+    redirect_to = request.REQUEST.get(redirect_field_name, '')
+    if not http_utils.is_safe_url(url=redirect_to, host=request.get_host()):
         redirect_to = settings.LOGIN_REDIRECT_URL
 
     for env in get_available_environments(request):
@@ -141,7 +102,7 @@ def switch(request, environment_id,
 
 def get_next_quick_environment_name(request):
     quick_env_prefix = 'quick-env-'
-    quick_env_re = re.compile(r'^' + quick_env_prefix + r'([\d]+)$')
+    quick_env_re = re.compile('^' + quick_env_prefix + '([\d]+)$')
 
     def parse_number(env):
         match = re.match(quick_env_re, env.name)
@@ -162,9 +123,7 @@ def create_quick_environment(request):
 
 
 def update_latest_apps(func):
-    """Update 'app_id's in session
-
-    Adds package id to a session queue with Applications which were
+    """Adds package id to a session queue with Applications which were
     recently added to an environment or to the Catalog itself. Thus it is
     used as decorator for views adding application to an environment or
     uploading new package definition to a catalog.
@@ -185,24 +144,23 @@ def update_latest_apps(func):
     return __inner
 
 
-def cleaned_latest_apps(request):
-    """Returns a list of recently used apps
-
-    Verifies, that apps in the list are either public or belong to current
-    project.
-    """
-    id_param = "in:" + ",".join(request.session.get('latest_apps', []))
-    query_params = {'type': 'Application', 'catalog': True, 'id': id_param}
-    user_apps = list(api.muranoclient(request).packages.filter(**query_params))
-    request.session['latest_apps'] = collections.deque([app.id
-                                                        for app in user_apps])
-    return user_apps
+def clean_latest_apps(request):
+    cleaned_apps, cleaned_app_ids = [], []
+    for app_id in request.session.get('latest_apps', []):
+        try:
+            app = api.muranoclient(request).packages.get(app_id)
+        except exc.HTTPNotFound:
+            pass
+        else:
+            if app.type == 'Application':
+                cleaned_apps.append(app)
+                cleaned_app_ids.append(app_id)
+    request.session['latest_apps'] = collections.deque(cleaned_app_ids)
+    return cleaned_apps
 
 
 def clear_forms_data(func):
-    """Removes form data from session
-
-    Clears user's session from a data for a specific application. It
+    """Clears user's session from a data for a specific application. It
     guarantees that previous additions of that application won't interfere
     with the next ones. Should be used as a decorator for entry points for
     adding an application in an environment.
@@ -214,7 +172,7 @@ def clear_forms_data(func):
         LOG.debug('Clearing forms data for application {0}.'.format(fqn))
         services.get_apps_data(request)[app_id] = {}
         LOG.debug('Clearing any leftover wizard step data.')
-        for key in list(request.session.keys()):
+        for key in request.session.keys():
             # TODO(tsufiev): unhardcode the prefix for wizard step data
             if key.startswith('wizard_wizard'):
                 request.session.pop(key)
@@ -253,12 +211,7 @@ def quick_deploy(request, app_id):
 
 
 def get_image(request, app_id):
-    try:
-        content = pkg_api.get_app_logo(request, app_id)
-    except (AttributeError, exc.HTTPNotFound):
-        message = _("Can not get logo for {0}.").format(app_id)
-        LOG.warning(message)
-        content = None
+    content = pkg_api.get_app_logo(request, app_id)
     if content:
         return http.HttpResponse(content=content, content_type='image/png')
     else:
@@ -267,12 +220,7 @@ def get_image(request, app_id):
 
 
 def get_supplier_image(request, app_id):
-    try:
-        content = pkg_api.get_app_supplier_logo(request, app_id)
-    except (AttributeError, exc.HTTPNotFound):
-        message = _("Can not get supplier logo for {0}.").format(app_id)
-        LOG.warning(message)
-        content = None
+    content = pkg_api.get_app_supplier_logo(request, app_id)
     if content:
         return http.HttpResponse(content=content, content_type='image/png')
     else:
@@ -281,9 +229,7 @@ def get_supplier_image(request, app_id):
 
 
 class LazyWizard(wizard_views.SessionWizardView):
-    """Lazy version of SessionWizardView
-
-    The class which defers evaluation of form_list and condition_dict
+    """The class which defers evaluation of form_list and condition_dict
     until view method is called. So, each time we load a page with a dynamic
     UI form, it will have markup/logic from the newest YAML-file definition.
     """
@@ -330,49 +276,34 @@ class LazyWizard(wizard_views.SessionWizardView):
         return view
 
 
-class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
+class Wizard(views.ModalFormMixin, LazyWizard):
     template_name = 'services/wizard_create.html'
     do_redirect = False
-    page_title = _("Add Application")
 
     def get_prefix(self, *args, **kwargs):
         base = super(Wizard, self).get_prefix(*args, **kwargs)
         fmt = utils.BlankFormatter()
         return fmt.format('{0}_{app_id}', base, **kwargs)
 
-    def get_form_prefix(self, step=None, form=None):
-        if step is None:
-            return self.steps.step0
-        else:
-            index0 = self.steps.all.index(step)
-            return str(index0)
-
     def done(self, form_list, **kwargs):
-        app_name = self.storage.extra_data['app'].name
-        service = tuple(form_list)[0].service
-        try:
-            attributes = service.extract_attributes()
-        except castellan_exception.KeyManagerError as e:
-            msg = _("This Application requires encryption, please contact "
-                    "your administrator to configure this.")
-            messages.error(self.request, msg)
-            LOG.exception(e)
-            raise
+        app_id = kwargs['app_id']
+        app_name = services.get_service_name(self.request, app_id)
+
+        service = form_list[0].service
+        attributes = service.extract_attributes()
         attributes = helpers.insert_hidden_ids(attributes)
 
         storage = attributes.setdefault('?', {}).setdefault(
             consts.DASHBOARD_ATTRS_KEY, {})
         storage['name'] = app_name
-        attributes['?']['resourceUsages'] = self.aggregate_usages(
-            self.init_usages()[1:])
 
-        do_redirect = self.get_wizard_flag('do_redirect')
         wm_form_data = service.cleaned_data.get('workflowManagement')
         if wm_form_data:
-            do_redirect = do_redirect or not wm_form_data.get(
-                'stay_at_the_catalog', True)
+            do_redirect = not wm_form_data['StayAtCatalog']
+        else:
+            do_redirect = self.get_wizard_flag('do_redirect')
 
-        fail_url = reverse("horizon:app-catalog:environments:index")
+        fail_url = reverse("horizon:murano:environments:index")
         environment_id = utils.ensure_python_obj(kwargs.get('environment_id'))
         quick_environment_id = self.request.session.get('quick_env_id')
         try:
@@ -386,7 +317,7 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
                     environment_id = env.id
                 else:
                     environment_id = quick_environment_id
-            env_url = reverse('horizon:app-catalog:environments:services',
+            env_url = reverse('horizon:murano:environments:services',
                               args=(environment_id,))
 
             srv = env_api.service_create(
@@ -400,7 +331,7 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
             LOG.exception(message)
             if quick_environment_id:
                 env_api.environment_delete(self.request, quick_environment_id)
-                fail_url = reverse('horizon:app-catalog:catalog:index')
+                fail_url = reverse('horizon:murano:catalog:index')
             exceptions.handle(self.request, message, redirect=fail_url)
         else:
             message = _("The '{0}' application successfully added to "
@@ -409,21 +340,19 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
             messages.success(self.request, message)
 
             if do_redirect:
-                return http.HttpResponseRedirect(str(env_url))
+                return http.HttpResponseRedirect(env_url)
             else:
                 srv_id = getattr(srv, '?')['id']
-                return self.create_hacked_response(
-                    srv_id,
-                    attributes['?'].get('name') or attributes.get('name'))
+                return self.create_hacked_response(srv_id, attributes['name'])
 
     def create_hacked_response(self, obj_id, obj_name):
         # copy-paste from horizon.forms.views.ModalFormView; should be done
         # that way until we move here from django Wizard to horizon workflow
         if views.ADD_TO_FIELD_HEADER in self.request.META:
             field_id = self.request.META[views.ADD_TO_FIELD_HEADER]
-            response = http.HttpResponse(
-                json.dumps([obj_id, html.escape(obj_name)]),
-                content_type='text/plain')
+            response = http.HttpResponse(json.dumps(
+                [obj_id, html.escape(obj_name)]
+            ))
             response["X-Horizon-Add-To-Field"] = field_id
             return response
         else:
@@ -447,137 +376,11 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
         value = self._get_wizard_param(key)
         return utils.ensure_python_obj(value)
 
-    def get_flavors(self):
-        try:
-            flavors = nova.flavor_list(self.request)
-        except nova_exceptions.ClientException:
-            message = _("Failed to get list of flavors.")
-            exceptions.handle(self.request, message)
-            LOG.exception(message)
-            flavors = []
-
-        def extract(flavor):
-            info = flavor._info
-            return {k: v for (k, v) in info.items() if k != 'links'}
-        flavors = [extract(f) for f in flavors]
-        self.storage.extra_data['flavors'] = flavors
-        return json.dumps(flavors)
-
-    def get_flavor_usages(self, form):
-        selected_flavor = form.cleaned_data['flavor']
-        for flavor in self.storage.extra_data['flavors']:
-            if flavor['name'] == selected_flavor:
-                return {'ram': flavor['ram'],
-                        'vcpus': flavor['vcpus'],
-                        'instances': 1}
-
-    def init_usages(self):
-        stored_data = self.storage.extra_data
-        step_usages = stored_data.get('step_usages')
-        if step_usages is None:
-            step_usages = [
-                collections.defaultdict(dict)
-                for step in self.steps.all
-            ]
-            stored_data['step_usages'] = step_usages
-
-            environment_id = self.kwargs.get('environment_id')
-            environment_id = utils.ensure_python_obj(environment_id)
-            if environment_id is not None:
-                session_id = env_api.Session.get(self.request, environment_id)
-                client = api.muranoclient(self.request)
-                all_services = client.environments.get(
-                    environment_id, session_id).services
-                env_usages = self.aggregate_usages(map(
-                    lambda svc: svc['?'].get('resourceUsages', {}),
-                    all_services))
-            else:
-                env_usages = collections.defaultdict(dict)
-            step_usages.insert(0, env_usages)
-
-        return step_usages
-
-    def process_step(self, form):
-        data = super(Wizard, self).process_step(form)
-        region = form.region or self.request.user.services_region
-        step_usages = self.init_usages()
-        if 'flavor' in form.cleaned_data:
-            usages = self.get_flavor_usages(form)
-            step_usages[self.steps.step0 + 1][region].update({
-                'ram': usages['ram'],
-                'vcpus': usages['vcpus'],
-                'instances': usages['instances']
-            })
-        else:
-            step_usages[self.steps.step0 + 1][region].update({
-                'ram': 0,
-                'vcpus': 0,
-                'instances': 0
-            })
-
-        return data
-
-    def update_usages(self, form, context):
-        data = self.init_usages()
-        usages = quotas.tenant_quota_usages(self.request).usages
-        region = self.request.user.services_region
-        inf = float('inf')
-
-        def get_usage(group, name, default):
-            return usages.get(group, {}).get(name, default)
-
-        context.update({
-            'usages': {
-                'maxTotalInstances': get_usage('instances', 'quota', inf),
-                'totalInstancesUsed': get_usage('instances', 'used', 0),
-                'maxTotalCores': get_usage('cores', 'quota', inf),
-                'totalCoresUsed': get_usage('cores', 'used', 0),
-                'maxTotalRAMSize': get_usage('ram', 'quota', inf),
-                'totalRAMUsed': get_usage('ram', 'used', 0),
-            },
-            'other_usages': {},
-            'flavors': self.get_flavors(),
-            'contexts': ['', 'info', 'success']
-        })
-        for step in range(self.steps.step0 + 1):
-
-            def sum_usage(context_key, data_key):
-                if context_key not in context['other_usages']:
-                    context['other_usages'][context_key] = 0
-                context['other_usages'][context_key] += \
-                    data[step][region].get(data_key, 0)
-            sum_usage('totalInstancesUsed', 'instances')
-            sum_usage('totalCoresUsed', 'vcpus')
-            sum_usage('totalRAMUsed', 'ram')
-
-        return context
-
-    @staticmethod
-    def aggregate_usages(steps):
-        result = collections.defaultdict(dict)
-        for step in steps:
-            for region, region_usages in iter(step.items()):
-                for metric, value in iter(region_usages.items()):
-                    if metric not in result[region]:
-                        result[region][metric] = 0
-                    result[region][metric] += value
-        return result
-
     def get_context_data(self, form, **kwargs):
         context = super(Wizard, self).get_context_data(form=form, **kwargs)
         mc = api.muranoclient(self.request)
         app_id = self.kwargs.get('app_id')
-        app = self.storage.extra_data.get('app')
-
-        # Save extra data to prevent extra API calls
-        if not app:
-            app = mc.packages.get(app_id)
-            self.storage.extra_data['app'] = app
-
-        wizard_id = self.request.POST.get('wizard_id')
-        if wizard_id is None:
-            wizard_id = uuid.uuid4()
-
+        app = mc.packages.get(app_id)
         environment_id = self.kwargs.get('environment_id')
         environment_id = utils.ensure_python_obj(environment_id)
         if environment_id is not None:
@@ -585,9 +388,8 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
         else:
             env_name = get_next_quick_environment_name(self.request)
 
-        field_descr, extended_descr = services.get_app_field_descriptions(
+        context['field_descriptions'] = services.get_app_field_descriptions(
             self.request, app_id, self.steps.index)
-
         context.update({'type': app.fully_qualified_name,
                         'service_name': app.name,
                         'app_id': app_id,
@@ -596,18 +398,12 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
                         'do_redirect': self.get_wizard_flag('do_redirect'),
                         'drop_wm_form': self.get_wizard_flag('drop_wm_form'),
                         'prefix': self.prefix,
-                        'wizard_id': wizard_id,
-                        'field_descriptions': field_descr,
-                        'extended_descriptions': extended_descr,
                         })
-        with helpers.current_region(self.request, form.region):
-            context = self.update_usages(form, context)
         return context
 
 
-class IndexView(generic_views.PageTitleMixin, list_view.ListView):
+class IndexView(list_view.ListView):
     paginate_by = 6
-    page_title = _("Browse")
 
     def __init__(self, **kwargs):
         super(IndexView, self).__init__(**kwargs)
@@ -618,14 +414,12 @@ class IndexView(generic_views.PageTitleMixin, list_view.ListView):
         return datum.id
 
     def get_marker(self, index=-1):
-        """Get the pagination marker
-
-        Returns the identifier for the object indexed by ``index`` in the
+        """Returns the identifier for the object indexed by ``index`` in the
         current data set for APIs that use marker/limit-based paging.
         """
         data = self.object_list
         if data:
-            return parse.quote_plus(self.get_object_id(data[index]))
+            return http_utils.urlquote_plus(self.get_object_id(data[index]))
         else:
             return ''
 
@@ -636,34 +430,27 @@ class IndexView(generic_views.PageTitleMixin, list_view.ListView):
             query_params = {}
         category = self.get_current_category()
         search = self.request.GET.get('search')
-
         if search:
             query_params['search'] = search
         else:
             if category != ALL_CATEGORY_NAME:
                 query_params['category'] = category
 
-        query_params['order_by'] = self.request.GET.get('order_by', 'name')
-        query_params['sort_dir'] = self.request.GET.get('sort_dir', 'asc')
         return query_params
 
     def get_queryset(self):
         query_params = self.get_query_params(internal_query=True)
         marker = self.request.GET.get('marker')
-
-        sort_dir = query_params['sort_dir']
+        sort_dir = self.request.GET.get('sort_dir')
 
         packages = []
         with api.handled_exceptions(self.request):
-            query_params['catalog'] = True
             packages, self._more = pkg_api.package_list(
                 self.request, filters=query_params, paginate=True,
-                marker=marker, page_size=self.paginate_by, sort_dir=sort_dir,
-                limit=self.paginate_by)
+                marker=marker, page_size=self.paginate_by, sort_dir=sort_dir)
 
         if sort_dir == 'desc':
-            packages = list(reversed(packages))
-
+            packages.reverse()
         return packages
 
     def get_template_names(self):
@@ -674,8 +461,6 @@ class IndexView(generic_views.PageTitleMixin, list_view.ListView):
             return self._more
         else:
             query_params = self.get_query_params(internal_query=True)
-            query_params['sort_dir'] = 'asc'
-            query_params['catalog'] = True
             packages, more = pkg_api.package_list(
                 self.request, filters=query_params, paginate=True,
                 marker=self.get_marker(), page_size=1)
@@ -703,53 +488,50 @@ class IndexView(generic_views.PageTitleMixin, list_view.ListView):
             query_params['marker'] = marker
         if sort_dir:
             query_params['sort_dir'] = sort_dir
-        return '{0}?{1}'.format(reverse('horizon:app-catalog:catalog:index'),
+        return '{0}?{1}'.format(reverse('horizon:murano:catalog:index'),
                                 http_utils.urlencode(query_params))
 
     def prev_page_url(self):
         query_params = self.get_query_params()
-        query_params['marker'] = self.get_marker(0)
-        query_params['sort_dir'] = 'desc'
-        return '{0}?{1}'.format(reverse('horizon:app-catalog:catalog:index'),
+        query_params.update({'marker': self.get_marker(0),
+                             'sort_dir': 'desc'})
+        return '{0}?{1}'.format(reverse('horizon:murano:catalog:index'),
                                 http_utils.urlencode(query_params))
 
     def next_page_url(self):
         query_params = self.get_query_params()
         query_params['marker'] = self.get_marker()
-        query_params['sort_dir'] = 'asc'
-        return '{0}?{1}'.format(reverse('horizon:app-catalog:catalog:index'),
+        return '{0}?{1}'.format(reverse('horizon:murano:catalog:index'),
                                 http_utils.urlencode(query_params))
 
     def get_context_data(self, **kwargs):
         context = super(IndexView, self).get_context_data(**kwargs)
 
+        categories = []
+        with api.handled_exceptions(self.request):
+            client = api.muranoclient(self.request)
+            categories = client.packages.categories()
+        if ALL_CATEGORY_NAME not in categories:
+            categories.insert(0, ALL_CATEGORY_NAME)
+
         context.update({
-            'ALL_CATEGORY_NAME': ALL_CATEGORY_NAME,
-            'categories': get_categories_list(self.request),
+            'categories': categories,
             'current_category': self.get_current_category(),
-            'latest_list': cleaned_latest_apps(self.request)
+            'latest_list': clean_latest_apps(self.request)
         })
 
         search = self.request.GET.get('search')
         if search:
             context['search'] = search
 
-        context['tenant_id'] = self.request.session['token'].tenant['id']
         context.update(get_environments_context(self.request))
-        context['display_repo_url'] = pkg_consts.DISPLAY_MURANO_REPO_URL
-        context['pkg_def_url'] = reverse('horizon:app-catalog:packages:index')
-        context['no_apps'] = True
-        if self.get_current_category() != ALL_CATEGORY_NAME or search:
-            context['no_apps'] = False
-        context['MURANO_USE_GLARE'] = getattr(settings, 'MURANO_USE_GLARE',
-                                              False)
+
         return context
 
 
 class AppDetailsView(tabs.TabView):
     tab_group_class = catalog_tabs.ApplicationTabs
     template_name = 'catalog/app_details.html'
-    page_title = '{{ app.name }}'
 
     app = None
 
