@@ -16,10 +16,9 @@ import os
 import tempfile
 
 from django.conf import settings
-from django.utils.translation import gettext_lazy as _
 
 
-# ---- Metadata Consts ---- #
+#---- Metadata Consts ----#
 CHUNK_SIZE = 1 << 20  # 1MB
 ARCHIVE_PKG_NAME = 'archive.tar.gz'
 CACHE_DIR = getattr(settings, 'METADATA_CACHE_DIR',
@@ -30,7 +29,7 @@ CACHE_REFRESH_SECONDS_INTERVAL = 5
 
 DASHBOARD_ATTRS_KEY = '_26411a1861294160833743e45d0eaad9'
 
-# ---- Forms Consts ---- #
+#---- Forms Consts ----#
 STATUS_ID_READY = 'ready'
 STATUS_ID_PENDING = 'pending'
 STATUS_ID_DEPLOYING = 'deploying'
@@ -63,36 +62,26 @@ STATUS_CHOICES = (
     (STATUS_ID_DELETING, None),
     (STATUS_ID_NEW, True),
     (STATUS_ID_DELETE_FAILURE, False),
-    (STATUS_ID_DEPLOY_FAILURE, False),
-)
-
-DEPLOYMENT_STATUS_CHOICES = (
-    (None, True),
-    (DEP_STATUS_ID_RUNNING, True),
-    (DEP_STATUS_ID_SUCCESS, True),
-    (DEP_STATUS_ID_RUNNING_W_ERRORS, False),
-    (DEP_STATUS_ID_RUNNING_W_WARNINGS, False),
-    (DEP_STATUS_ID_COMPLETED_W_WARNINGS, False),
-    (DEP_STATUS_ID_COMPLETED_W_ERRORS, False),
+    (STATUS_ID_DEPLOY_FAILURE, False)
 )
 
 STATUS_DISPLAY_CHOICES = (
-    (STATUS_ID_READY, _('Ready')),
-    (STATUS_ID_DEPLOYING, _('Deploying')),
-    (STATUS_ID_DELETING, _('Deleting')),
-    (STATUS_ID_PENDING, _('Ready to deploy')),
-    (STATUS_ID_NEW, _('Ready to configure')),
-    (STATUS_ID_DELETE_FAILURE, _('Delete failure')),
-    (STATUS_ID_DEPLOY_FAILURE, _('Deploy failure')),
-    ('', _('Ready to configure')),
+    (STATUS_ID_READY, 'Ready'),
+    (STATUS_ID_DEPLOYING, 'Deploy in progress'),
+    (STATUS_ID_DELETING, 'Delete in progress'),
+    (STATUS_ID_PENDING, 'Ready to deploy'),
+    (STATUS_ID_NEW, 'Ready to configure'),
+    (STATUS_ID_DELETE_FAILURE, 'Delete FAILURE'),
+    (STATUS_ID_DEPLOY_FAILURE, 'Deploy FAILURE'),
+    ('', 'Ready to configure'),
 )
 
 DEPLOYMENT_STATUS_DISPLAY_CHOICES = (
-    (DEP_STATUS_ID_COMPLETED_W_ERRORS, _('Failed')),
-    (DEP_STATUS_ID_COMPLETED_W_WARNINGS, _('Completed with warnings')),
-    (DEP_STATUS_ID_RUNNING, _('Running')),
-    (DEP_STATUS_ID_RUNNING_W_ERRORS, _('Running with errors')),
-    (DEP_STATUS_ID_RUNNING_W_WARNINGS, _('Running with warnings')),
-    (DEP_STATUS_ID_SUCCESS, _('Successful')),
-    ('', _('Unknown')),
+    (DEP_STATUS_ID_COMPLETED_W_ERRORS, 'Failed'),
+    (DEP_STATUS_ID_COMPLETED_W_WARNINGS, 'Completed with warnings'),
+    (DEP_STATUS_ID_RUNNING, 'Running'),
+    (DEP_STATUS_ID_RUNNING_W_ERRORS, 'Running with errors'),
+    (DEP_STATUS_ID_RUNNING_W_WARNINGS, 'Running with warnings'),
+    (DEP_STATUS_ID_SUCCESS, 'Successful'),
+    ('', 'Unknown'),
 )
