@@ -12,27 +12,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
-import json
-
-from django.conf import settings
-from django.urls import reverse
-from django.utils.translation import gettext_lazy as _
-
-from heat_dashboard.api import heat as heat_api
+import logging
 
+from django.core.urlresolvers import reverse
+from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import tabs
 
-from openstack_dashboard.api import nova as nova_api
-from openstack_dashboard import policy
-
 from muranoclient.common import exceptions as exc
-from muranodashboard.common import utils
 from muranodashboard.environments import api
 from muranodashboard.environments import consts
 from muranodashboard.environments import tables
 
+LOG = logging.getLogger(__name__)
+
 
 class OverviewTab(tabs.Tab):
     name = _("Component")
@@ -45,37 +39,6 @@ class OverviewTab(tabs.Tab):
         :param request:
         :return:
         """
-        def find_stack(name, **kwargs):
-            stacks, has_more, has_prev = heat_api.stacks_list(
-                request, sort_dir='asc', **kwargs)
-            for stack in stacks:
-                if name in stack.stack_name:
-                    stack_data = {'id': stack.id,
-                                  'name': stack.stack_name}
-                    return stack_data
-            if has_more:
-                return find_stack(name, marker=stacks[-1].id)
-            return {}
-
-        def get_instance_and_stack(instance_data, request):
-            instance_name = instance_data['name']
-            nova_openstackid = instance_data['openstackId']
-            stack_name = ''
-            instance_result_data = {}
-            stack_result_data = {}
-            instances, more = nova_api.server_list(request)
-
-            for instance in instances:
-                if nova_openstackid in instance.id:
-                    instance_result_data = {'name': instance.name,
-                                            'id': instance.id}
-                    stack_name = instance.name.split('-' + instance_name)[0]
-                    break
-            # Add link to stack details page
-            if stack_name:
-                stack_result_data = find_stack(stack_name)
-            return instance_result_data, stack_result_data
-
         service_data = self.tab_group.kwargs['service']
 
         status_name = ''
@@ -83,10 +46,10 @@ class OverviewTab(tabs.Tab):
             if id == service_data['?']['status']:
                 status_name = name
 
-        detail_info = collections.OrderedDict([
+        detail_info = SortedDict([
             ('Name', getattr(service_data, 'name', '')),
             ('ID', service_data['?']['id']),
-            ('Type', tables.get_service_type(service_data) or 'Unknown'),
+            ('Type', service_data['?'][consts.DASHBOARD_ATTRS_KEY]['name']),
             ('Status', status_name), ])
 
         if hasattr(service_data, 'domain'):
@@ -104,34 +67,25 @@ class OverviewTab(tabs.Tab):
         if hasattr(service_data, 'floatingip'):
             detail_info['Floating IP'] = service_data.floatingip
 
-        # TODO(efedorova): Need to determine Instance subclass
-        # after it would be possible
-        if hasattr(service_data,
-                   'instance') and service_data['instance'] is not None:
-            instance, stack = get_instance_and_stack(
-                service_data['instance'], request)
-            if instance:
-                detail_info['Instance'] = instance
-            if stack:
-                detail_info['Stack'] = stack
-
-        if hasattr(service_data,
-                   'instances') and service_data['instances'] is not None:
-            instances_for_template = []
-            stacks_for_template = []
-            for instance in service_data['instances']:
-                instance, stack = get_instance_and_stack(instance, request)
-                instances_for_template.append(instance)
-                if stack:
-                    stacks_for_template.append(stack)
-            if instances_for_template:
-                detail_info['Instances'] = instances_for_template
-            if stacks_for_template:
-                detail_info['Stacks'] = stacks_for_template
-
         return {'service': detail_info}
 
 
+class AppActionsTab(tabs.Tab):
+    name = _('Actions')
+    slug = '_actions'
+    template_name = 'services/_actions.html'
+
+    def get_context_data(self, request):
+        data = self.tab_group.kwargs['service']
+        return {'actions': api.extract_actions_list(data),
+                'service_id': self.tab_group.kwargs['service_id'],
+                'environment_id': self.tab_group.kwargs['environment_id']}
+
+    def allowed(self, request):
+        environment_id = self.tab_group.kwargs['environment_id']
+        return api.action_allowed(request, environment_id)
+
+
 class ServiceLogsTab(tabs.Tab):
     name = _("Logs")
     slug = "service_logs"
@@ -155,17 +109,10 @@ class EnvLogsTab(tabs.Tab):
     def get_context_data(self, request):
         reports = self.tab_group.kwargs['logs']
         for report in reports:
-            report.created = utils.adjust_datestr(request, report.created)
+            report.created = report.created.replace('T', ' ')
         return {"reports": reports}
 
 
-class LatestLogsTab(EnvLogsTab):
-    name = _("Latest Deployment Log")
-
-    def allowed(self, request):
-        return self.data.get('reports')
-
-
 class EnvConfigTab(tabs.TableTab):
     name = _("Configuration")
     slug = "env_config"
@@ -184,12 +131,6 @@ class EnvironmentTopologyTab(tabs.Tab):
     template_name = "services/_detail_topology.html"
     preload = False
 
-    def allowed(self, request):
-        if self.data.get('d3_data'):
-            if json.loads(self.data['d3_data'])['environment']['status']:
-                return True
-        return False
-
     def get_context_data(self, request):
         context = {}
         environment_id = self.tab_group.kwargs['environment_id']
@@ -201,7 +142,7 @@ class EnvironmentTopologyTab(tabs.Tab):
 
 class EnvironmentServicesTab(tabs.TableTab):
     name = _("Components")
-    slug = "services"
+    slug = "serviceslist"
     table_classes = (tables.ServicesTable,)
     template_name = "services/_service_list.html"
     preload = False
@@ -209,7 +150,7 @@ class EnvironmentServicesTab(tabs.TableTab):
     def get_services_data(self):
         services = []
         self.environment_id = self.tab_group.kwargs['environment_id']
-        ns_url = "horizon:app-catalog:environments:index"
+        ns_url = "horizon:murano:environments:index"
         try:
             services = api.services_list(self.request, self.environment_id)
         except exc.HTTPForbidden:
@@ -227,13 +168,6 @@ class EnvironmentServicesTab(tabs.TableTab):
 
         return services
 
-    def get_context_data(self, request, **kwargs):
-        context = super(EnvironmentServicesTab,
-                        self).get_context_data(request, **kwargs)
-        context['MURANO_USE_GLARE'] = getattr(settings, 'MURANO_USE_GLARE',
-                                              False)
-        return context
-
 
 class DeploymentTab(tabs.TableTab):
     slug = "deployments"
@@ -242,13 +176,10 @@ class DeploymentTab(tabs.TableTab):
     template_name = 'horizon/common/_detail_table.html'
     preload = False
 
-    def allowed(self, request):
-        return policy.check((("murano", "list_deployments"),), request)
-
     def get_deployments_data(self):
         deployments = []
         self.environment_id = self.tab_group.kwargs['environment_id']
-        ns_url = "horizon:app-catalog:environments:index"
+        ns_url = "horizon:murano:environments:index"
         try:
             deployments = api.deployments_list(self.request,
                                                self.environment_id)
@@ -267,18 +198,14 @@ class DeploymentTab(tabs.TableTab):
 
 class EnvironmentDetailsTabs(tabs.TabGroup):
     slug = "environment_details"
-    tabs = (EnvironmentServicesTab, EnvironmentTopologyTab,
-            DeploymentTab, LatestLogsTab)
-    sticky = True
+    tabs = (EnvironmentServicesTab, EnvironmentTopologyTab, DeploymentTab)
 
 
 class ServicesTabs(tabs.TabGroup):
     slug = "services_details"
-    tabs = (OverviewTab, ServiceLogsTab)
-    sticky = True
+    tabs = (OverviewTab, AppActionsTab, ServiceLogsTab)
 
 
 class DeploymentDetailsTabs(tabs.TabGroup):
     slug = "deployment_details"
     tabs = (EnvConfigTab, EnvLogsTab,)
-    sticky = True
