@@ -14,19 +14,21 @@
 
 from django.conf import urls
 
+from muranodashboard.packages import forms
 from muranodashboard.packages import views
 
 
-urlpatterns = [
-    urls.url(r'^$', views.PackageDefinitionsView.as_view(), name='index'),
-    urls.url(r'^upload$', views.ImportPackageWizard.as_view(
-             views.FORMS), name='upload'),
-    urls.url(r'^import_bundle$', views.ImportBundleWizard.as_view(
-             views.BUNDLE_FORMS), name='import_bundle'),
+urlpatterns = urls.patterns(
+    '',
+    urls.url(r'^$', views.PackageDefinitionsView.as_view(),
+             name='index'),
+
+    urls.url(r'^upload$', views.UploadPackageWizard.as_view(
+        [forms.UploadPackageFileForm, forms.UpdatePackageForm]),
+        name='upload'),
+
     urls.url(r'^modify/(?P<app_id>[^/]+)?$',
-             views.ModifyPackageView.as_view(), name='modify'),
-    urls.url(r'^(?P<app_id>[^/]+)?$',
-             views.DetailView.as_view(), name='detail'),
-    urls.url(r'^download/(?P<app_name>[^/]+)/(?P<app_id>[^/]+)?$',
-             views.download_packge, name='download'),
-]
+             views.ModifyPackageView.as_view(),
+             name='modify'),
+
+)
